@@ -1,9 +1,18 @@
 import numpy
-numpy.seterr(all='raise')
 
+numpy.seterr(all="raise")
+
+from vivarium.__about__ import (
+    __author__,
+    __copyright__,
+    __email__,
+    __license__,
+    __summary__,
+    __title__,
+    __uri__,
+    __version__,
+)
 from vivarium.config_tree import ConfigTree
-from vivarium.interface import InteractiveContext
 from vivarium.framework.artifact import Artifact
 from vivarium.framework.configuration import build_model_specification
-from vivarium.__about__ import (__author__, __copyright__, __email__, __license__,
-                                __summary__, __title__, __uri__, __version__, )
+from vivarium.interface import InteractiveContext
