@@ -26,7 +26,7 @@ For more information, see the associated event
 :ref:`concept note <event_concept>`.
 
 """
-from typing import Callable, Dict, List, NamedTuple, Any, Optional
+from typing import Any, Callable, Dict, List, NamedTuple, Optional
 
 import pandas as pd
 
@@ -42,6 +42,7 @@ class Event(NamedTuple):
     to respond to them.
 
     """
+
     #: An index into the population table containing all simulants affected
     #: by this event.
     index: pd.Index
@@ -53,7 +54,7 @@ class Event(NamedTuple):
     #: The current step size at the time of the event.
     step_size: Timedelta
 
-    def split(self, new_index: pd.Index) -> 'Event':
+    def split(self, new_index: pd.Index) -> "Event":
         """Create a copy of this event with a new index.
 
         This function should be used to emit an event in a new
@@ -75,7 +76,9 @@ class Event(NamedTuple):
         return Event(new_index, self.user_data, self.time, self.step_size)
 
     def __repr__(self):
-        return f"Event(user_data={self.user_data}, time={self.time}, step_size={self.step_size})"
+        return (
+            f"Event(user_data={self.user_data}, time={self.time}, step_size={self.step_size})"
+        )
 
     def __eq__(self, other):
         return self.__dict__ == other.__dict__
@@ -85,7 +88,7 @@ class EventChannel:
     """A named subscription channel that passes events to event listeners."""
 
     def __init__(self, manager, name):
-        self.name = f'event_channel_{name}'
+        self.name = f"event_channel_{name}"
         self.manager = manager
         self.listeners = [[] for _ in range(10)]
 
@@ -107,9 +110,12 @@ class EventChannel:
         """
         if not user_data:
             user_data = {}
-        e = Event(index, user_data,
-                  self.manager.clock() + self.manager.step_size(),
-                  self.manager.step_size())
+        e = Event(
+            index,
+            user_data,
+            self.manager.clock() + self.manager.step_size(),
+            self.manager.step_size(),
+        )
 
         for priority_bucket in self.listeners:
             for listener in priority_bucket:
@@ -156,12 +162,14 @@ class EventManager:
         self.clock = builder.time.clock()
         self.step_size = builder.time.step_size()
 
-        builder.event.register_listener('post_setup', self.on_post_setup)
+        builder.event.register_listener("post_setup", self.on_post_setup)
         self.add_handlers = builder.lifecycle.add_handlers
         self.add_constraint = builder.lifecycle.add_constraint
 
-        builder.lifecycle.add_constraint(self.get_emitter, allow_during=['setup', 'simulation_end', 'report'])
-        builder.lifecycle.add_constraint(self.register_listener, allow_during=['setup'])
+        builder.lifecycle.add_constraint(
+            self.get_emitter, allow_during=["setup", "simulation_end", "report"]
+        )
+        builder.lifecycle.add_constraint(self.register_listener, allow_during=["setup"])
 
     def on_post_setup(self, event):
         for name, channel in self._event_types.items():
@@ -220,7 +228,11 @@ class EventManager:
             listeners to a list of listeners at that level.
         """
         channel = self.get_channel(name)
-        return {priority: listeners for priority, listeners in enumerate(channel.listeners) if listeners}
+        return {
+            priority: listeners
+            for priority, listeners in enumerate(channel.listeners)
+            if listeners
+        }
 
     def list_events(self) -> List[Event]:
         """List all event names known to the event system.
@@ -271,7 +283,9 @@ class EventInterface:
         """
         return self._manager.get_emitter(name)
 
-    def register_listener(self, name: str, listener: Callable[[Event], None], priority: int = 5) -> None:
+    def register_listener(
+        self, name: str, listener: Callable[[Event], None], priority: int = 5
+    ) -> None:
         """Registers a callable as a listener to a events with the given name.
 
         The listening callable will be called with a named ``Event`` as its
