@@ -17,21 +17,29 @@ dependencies or raise exceptions if this is not possible.
 
 """
 from types import MethodType
-from typing import Any, Callable, List, Iterable
+from typing import Any, Callable, Iterable, List
 
-from loguru import logger
 import networkx as nx
+from loguru import logger
 
 from vivarium.exceptions import VivariumError
 
 
 class ResourceError(VivariumError):
     """Error raised when a dependency requirement is violated."""
+
     pass
 
 
-RESOURCE_TYPES = {'value', 'value_source', 'missing_value_source', 'value_modifier', 'column', 'stream'}
-NULL_RESOURCE_TYPE = 'null'
+RESOURCE_TYPES = {
+    "value",
+    "value_source",
+    "missing_value_source",
+    "value_modifier",
+    "column",
+    "stream",
+}
+NULL_RESOURCE_TYPE = "null"
 
 
 class ResourceGroup:
@@ -46,7 +54,13 @@ class ResourceGroup:
 
     """
 
-    def __init__(self, resource_type: str, resource_names: List[str], producer: Callable, dependencies: List[str]):
+    def __init__(
+        self,
+        resource_type: str,
+        resource_names: List[str],
+        producer: Callable,
+        dependencies: List[str],
+    ):
         self._resource_type = resource_type
         self._resource_names = resource_names
         self._producer = producer
@@ -64,7 +78,7 @@ class ResourceGroup:
     @property
     def names(self) -> List[str]:
         """The long names (including type) of all resources in this group."""
-        return [f'{self._resource_type}.{name}' for name in self._resource_names]
+        return [f"{self._resource_type}.{name}" for name in self._resource_names]
 
     @property
     def producer(self) -> Any:
@@ -80,12 +94,12 @@ class ResourceGroup:
         return iter(self.names)
 
     def __repr__(self) -> str:
-        resources = ', '.join(self)
-        return f'ResourceProducer({resources})'
+        resources = ", ".join(self)
+        return f"ResourceProducer({resources})"
 
     def __str__(self) -> str:
-        resources = ', '.join(self)
-        return f'({resources})'
+        resources = ", ".join(self)
+        return f"({resources})"
 
 
 class ResourceManager:
@@ -132,12 +146,19 @@ class ResourceManager:
             try:
                 self._sorted_nodes = list(nx.algorithms.topological_sort(self.graph))
             except nx.NetworkXUnfeasible:
-                raise ResourceError(f'The resource pool contains at least one cycle: '
-                                    f'{nx.find_cycle(self.graph)}.')
+                raise ResourceError(
+                    f"The resource pool contains at least one cycle: "
+                    f"{nx.find_cycle(self.graph)}."
+                )
         return self._sorted_nodes
 
-    def add_resources(self, resource_type: str, resource_names: List[str],
-                      producer: Any, dependencies: List[str]):
+    def add_resources(
+        self,
+        resource_type: str,
+        resource_names: List[str],
+        producer: Any,
+        dependencies: List[str],
+    ):
         """Adds managed resources to the resource pool.
 
         Parameters
@@ -162,20 +183,31 @@ class ResourceManager:
 
         """
         if resource_type not in RESOURCE_TYPES:
-            raise ResourceError(f'Unknown resource type {resource_type}. '
-                                f'Permitted types are {RESOURCE_TYPES}.')
+            raise ResourceError(
+                f"Unknown resource type {resource_type}. "
+                f"Permitted types are {RESOURCE_TYPES}."
+            )
 
-        resource_group = self._get_resource_group(resource_type, resource_names, producer, dependencies)
+        resource_group = self._get_resource_group(
+            resource_type, resource_names, producer, dependencies
+        )
 
         for resource in resource_group:
             if resource in self._resource_group_map:
                 other_producer = self._resource_group_map[resource].producer
-                raise ResourceError(f'Both {producer} and {other_producer} are registered as '
-                                    f'producers for {resource}.')
+                raise ResourceError(
+                    f"Both {producer} and {other_producer} are registered as "
+                    f"producers for {resource}."
+                )
             self._resource_group_map[resource] = resource_group
 
-    def _get_resource_group(self, resource_type: str, resource_names: List[str],
-                            producer: MethodType, dependencies: List[str]) -> ResourceGroup:
+    def _get_resource_group(
+        self,
+        resource_type: str,
+        resource_names: List[str],
+        producer: MethodType,
+        dependencies: List[str],
+    ) -> ResourceGroup:
         """Packages resource information into a resource group.
 
         See Also
@@ -218,8 +250,10 @@ class ResourceManager:
                 if dependency not in self._resource_group_map:
                     # Warn here because this sometimes happens naturally
                     # if observer components are missing from a simulation.
-                    logger.warning(f'Resource {dependency} is not provided by any component but is needed to '
-                                   f'compute {resource_group}.')
+                    logger.warning(
+                        f"Resource {dependency} is not provided by any component but is needed to "
+                        f"compute {resource_group}."
+                    )
                     continue
                 dependency_group = self._resource_group_map[dependency]
                 resource_graph.add_edge(dependency_group, resource_group)
@@ -234,14 +268,20 @@ class ResourceManager:
         creation time.
 
         """
-        return iter([r.producer for r in self.sorted_nodes if r.type in {'column', NULL_RESOURCE_TYPE}])
+        return iter(
+            [
+                r.producer
+                for r in self.sorted_nodes
+                if r.type in {"column", NULL_RESOURCE_TYPE}
+            ]
+        )
 
     def __repr__(self):
         out = {}
         for resource_group in set(self._resource_group_map.values()):
-            produced = ', '.join(resource_group)
-            out[produced] = ', '.join(resource_group.dependencies)
-        return '\n'.join([f'{produced} : {depends}' for produced, depends in out.items()])
+            produced = ", ".join(resource_group)
+            out[produced] = ", ".join(resource_group.dependencies)
+        return "\n".join([f"{produced} : {depends}" for produced, depends in out.items()])
 
 
 class ResourceInterface:
@@ -265,8 +305,13 @@ class ResourceInterface:
     def __init__(self, manager: ResourceManager):
         self._manager = manager
 
-    def add_resources(self, resource_type: str, resource_names: List[str],
-                      producer: Any, dependencies: List[str]):
+    def add_resources(
+        self,
+        resource_type: str,
+        resource_names: List[str],
+        producer: Any,
+        dependencies: List[str],
+    ):
         """Adds managed resources to the resource pool.
 
         Parameters
